#
# spec file for package lua-lgi
#
# Copyright (c) 2021 SUSE LLC
# Copyright (c) 2012 Adam Mizerski <adam@mizerski.pl>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define flavor lua51
%define mod_name lgi
Version:        0.9.2
Release:        4.4
Summary:        Lua bindings to GObject libraries
License:        MIT
Group:          Development/Languages/Other
URL:            https://github.com/pavouk/lgi
Source0:        https://github.com/pavouk/%{mod_name}/archive/%{version}.tar.gz#/%{mod_name}-%{version}.tar.gz
Patch:          lua54.patch
BuildRequires:  lua-macros
BuildRequires:  %{flavor}-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gmodule-2.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0) >= 0.10.8
BuildRequires:  pkgconfig(libffi)
Requires:       %{flavor}
%lua_provides
%if "%{flavor}" == ""
Name:           lua-%{mod_name}
ExclusiveArch:  do_not_build
%else
Name:           %{flavor}-%{mod_name}
%endif

%description
Dynamic Lua binding to any library which is introspectable
using gobject-introspection. Allows using GObject-based libraries
directly from Lua.

%package doc
Summary:        Lua bindings to GObject libraries - documentation and samples
Group:          Documentation/Other

%description doc
Dynamic Lua binding to any library which is introspectable
using gobject-introspection. Allows using GObject-based libraries
directly from Lua.

%prep
%autosetup -n %{mod_name}-%{version} -p1

%build
make %{?_smp_mflags} V=1 \
  LUA_CFLAGS=" -I%{lua_incdir}" \
  COPTFLAGS="%{optflags}" \

%install
%make_install \
  PREFIX=%{_prefix} \
  LUA_LIBDIR=%{lua_archdir} \
  LUA_SHAREDIR=%{lua_noarchdir}

%files
%if 0%{?suse_version} >= 1500
%license LICENSE
%else
%doc LICENSE
%endif
%doc README.md
%{lua_archdir}/%{mod_name}/
%{lua_noarchdir}/%{mod_name}.lua
%{lua_noarchdir}/%{mod_name}/

%files doc
%doc docs samples tools

%changelog
* Wed Jan 25 2023 Michal Suchanek <msuchanek@suse.de>
- Fix missing dependency on lua-macros (boo#1205612)
* Tue Feb  9 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%lua_provides: add the lua-mod_name provides/obsoletes to
  the lua version matching the distro default.
* Thu Jul  9 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Added lua54.patch to fix building with Lua 5.4
* Mon Jul  6 2020 Matej Cepl <mcepl@suse.com>
- Add lua54 as new build target
* Wed Apr  4 2018 sor.alexei@meowr.ru
- Update to version 0.9.2:
  * Fix assorted crashes in closure callback invocation code.
  * Fix a double-free bug caused by incorrect annotation of
    Gio.DBusProxy.get_interface_info.
  * Fix marshaling of arrays of pointers.
  * Make objects unusable in __gc metamethod.
  * Work around an API break in GLib 2.54.
  * Use structured GLib logging when available.
  * Add Gio.Async support also for static methods and global
    functions.
  * A better error message when Gtk.init fails.
  * Add support for Travis.
  * Do not hardcode the pkg-config executable.
  * Fix URI in GStreamer sample.
  * Fix flags for D-Bus samples.
* Mon Oct 30 2017 jmatejek@suse.com
- do not build for Lua 5.2
* Mon Aug  7 2017 jengelh@inai.de
- RPM group corrections
* Thu Jul 13 2017 tchvatal@suse.com
- Switch to mutlibuild in order to compile all flavors as needed
* Sat May 28 2016 sor.alexei@meowr.ru
- Update to version 0.9.1:
  * Marshal NULL strings as nil instead of empty strings.
    This allows use of e.g. DataInputStream:read_line() APIs.
  * Add support for arrays with lengths as struct fields.
  * Allow GLib.Variant construction for lightuserdata.
  * Fix gtop binding (certain structs could not be imported).
  * Adapt to new set of annotations in newer GLib.
  * Assorted Lua5.3 fixes, lgi is now fully Lua5.3 compatible.
  * Fix binding of Gdk.Rectangle from newer Gdk.
* Wed Sep  2 2015 dimstar@opensuse.org
- Only depend on Lua(API) in Tumbleweed: openSUSE 13.2, Leap and
  SLE12 do not yet provide this symbol.
* Thu Jul 30 2015 dimstar@opensuse.org
- Depend on Lua(API) = %%{%%lua_version}. Note: lua_version is only
  major.minor of lua (e.g 5.2, 5.3[...]). This is needed as the
  files are installed in /usr/share/lua/5.2 when built against
  lua 5.2.
* Wed Apr 29 2015 sor.alexei@meowr.ru
- Update to 0.9.0:
  * Allow defining new properties on custom GObject subclasses
    implemented using lgi.
  * Improve compatibility with locales (turkish).
  * Fix GPtrArray handling.
  * Improve behavior when running in assorted multiple-embedded and
    concurrent scenarios.
* Fri Aug 15 2014 freyes@suse.com
- new upstream package; version 0.8.0
* Tue Jan  8 2013 adam@mizerski.pl
- new package; version 0.6.2
